JavascriptPosixSpawnFileAction

Struct JavascriptPosixSpawnFileAction 

pub struct JavascriptPosixSpawnFileAction {
    pub command: u32,
    pub guest_fd: Option<i32>,
    pub fd: i32,
    pub source_fd: i32,
    pub guest_source_fd: Option<i32>,
    pub oflag: i32,
    pub mode: u32,
    pub path: String,
    pub close_from_guest_fds: Vec<u32>,
}

Fields

command: u32guest_fd: Option<i32>fd: i32source_fd: i32guest_source_fd: Option<i32>oflag: i32mode: u32path: Stringclose_from_guest_fds: Vec<u32>

Runner-local public guest descriptors selected by closefrom. These do not have kernel mappings, but the child bootstrap must still suppress their untagged aliases while retaining private tagged preopens.